-------- 1/ CRÉER UNE BASE DE DONNÉES DANS POSTGRESQL --------

-- Création de la base de données (à partir d'une autre base de données du serveur PostgreSQL)
DROP DATABASE IF EXISTS mci_webinar3;
CREATE DATABASE mci_webinar3
 WITH ENCODING='UTF8'
 OWNER=postgres
 CONNECTION LIMIT=25;
 
 ---Ajouter l'extension POSTGIS
 CREATE EXTENSION IF NOT EXISTS postgis;

-- Se connecter à la base de données mci_webinar3
-- ex, avec la commande "psql -U postgres -d mci_webinar3" sur linux

-- Création d'un schéma 'mci'
DROP SCHEMA IF EXISTS mci CASCADE;
CREATE SCHEMA mci;

-------- 2/ CRÉER DES TABLES D’IMPORT ET IMPORTER LES DONNÉES --------

-- Création de la table import_addr_coax
DROP TABLE IF EXISTS mci.import_addr_coax;
CREATE TABLE mci.import_addr_coax (
coax_id integer,
coax_bat_x integer,
coax_bat_y integer,
coax_bat_syst_proj integer,
coax_nom_voie character varying(50),
coax_numero integer,
coax_complement character varying(6),
coax_code_insee character varying(5),
coax_debit_montant integer,
coax_debit_descendant integer,
ban_lat float,
ban_long float,
ban_label character varying(155),
ban_score float,
ban_type character varying(20),
ban_code character varying(20)
);

-- Copie des données de certains champs du fichier base_addr_coax_retour_API.csv dans la table mci.import_addr_coax
\COPY mci.import_addr_coax from '/home/debian/test/webinar_3/base_addr_coax_retour_API.csv' delimiter ';' CSV header; --Mettre à jour selon le chemin de votre fichier

-------- 3/ FILTRER et EFFECTUER DES CALCULS SUR LES DONNEES --------

-- Création de la table qui ne garde que les adresses qu'on estime geocodables
DROP TABLE IF EXISTS mci.addr_coax_dist;
CREATE TABLE mci.addr_coax_dist (
coax_id integer,
coax_bat_x integer,
coax_bat_y integer,
coax_bat_syst_proj integer,
coax_nom_voie character varying(50),
coax_numero integer,
coax_complement character varying(6),
coax_code_insee character varying(5),
coax_debit_montant integer,
coax_debit_descendant integer,
ban_lat float,
ban_long float,
ban_label character varying(155),
ban_score float,
ban_type character varying(20),
ban_code character varying(20),
distance float
);

--on ne récupère les adresses BAN que si le score BAN est >0,6 et si le type BAN est 'housenumber' ou 'locality'
---on le fait à cette étape pour ne calculer les distances que sur les adresses BAN géocodales
INSERT INTO mci.addr_coax_dist
SELECT * FROM mci.import_addr_coax
WHERE ban_score>0.6 AND (ban_type='housenumber' OR ban_type='locality');

---select coax_id, coax_numero, coax_nom_voie, coax_code_insee, ban_score, ban_type from mci.addr_coax_dist;


UPDATE mci.addr_coax_dist 
SET distance= ST_Distance(
					ST_SetSRID( ST_Point( coax_bat_x, coax_bat_y), 2154),
					ST_Transform(ST_SetSRID( ST_Point( ban_long, ban_lat), 4326),2154)
					);

---select coax_id, coax_numero, coax_nom_voie, coax_code_insee, ban_score, ban_type, distance from mci.addr_coax_dist;

-- Création de la table qui prend toutes les adresses de import et ajoute un code BAN si le géocodage répond aux 3 critères
DROP TABLE IF EXISTS mci.export_addr_coax;
CREATE TABLE mci.export_addr_coax (
coax_id integer,
coax_bat_x integer,
coax_bat_y integer,
coax_bat_syst_proj integer,
coax_nom_voie character varying(50),
coax_numero integer,
coax_complement character varying(6),
coax_code_insee character varying(5),
coax_debit_montant integer,
coax_debit_descendant integer,
ban_code character varying(20)
);

---Insert les donnnées initiales de import (toutes les adresses)
INSERT INTO mci.export_addr_coax
SELECT coax_id, coax_bat_x, coax_bat_y, coax_bat_syst_proj, coax_nom_voie, coax_numero, coax_complement, coax_code_insee, coax_debit_montant, coax_debit_descendant 
FROM mci.import_addr_coax;

UPDATE mci.export_addr_coax export
SET ban_code=(SELECT ban_code 
				FROM mci.addr_coax_dist dist
				WHERE dist.coax_id=export.coax_id AND dist.distance<150);


-------- 4/ EXPORTER LES DONNEES --------

-- Export de la table export_addr_coax
\COPY mci.export_addr_coax to '/home/debian/test/webinar_3/export_addr_coax.csv' delimiter ';' CSV header;
